from charmhelpers.core.hookenv import (
    config,
    service_name
)

from charmhelpers.contrib.openstack.context import (
    OSContextGenerator,
)


class VMwareIncompleteConfiguration(Exception):
    pass


class VMwareSubordinateContext(OSContextGenerator):
    interfaces = ['ceph-vmware']

    _config_keys = [
        'host-ip',
        'host-username',
        'host-password',
        'volume-folder',
    ]

    def __call__(self):
        ctxt = []
        missing = []
        for k in self._config_keys:
            if config(k):
                ctxt.append(("vmware_{}".format(k.replace('-', '_')),
                             config(k)))
            else:
                missing.append(k)
        if missing:
            raise VMwareIncompleteConfiguration(
                'Missing configuration: {}.'.format(missing)
            )

        service = service_name()
        volume_driver = 'cinder.volume.drivers.vmware.vmdk.VMwareVcVmdkDriver'
        ctxt.append(('volume_backend_name', service))
        ctxt.append(('volume_driver', volume_driver))
        return {
            "cinder": {
                "/etc/cinder/cinder.conf": {
                    "sections": {
                        service: ctxt
                    }
                }
            }
        }
