from mock import patch
import json

from test_utils import (
    CharmTestCase,
)

import cinder_hooks as hooks

TO_PATCH = [
    # charmhelpers.core.hookenv
    'relation_ids',
    'relation_set',
    'service_name',
    'log',
    'execd_preinstall',
    'VMwareSubordinateContext'
]


class TestCinderHooks(CharmTestCase):
    def setUp(self):
        super(TestCinderHooks, self).setUp(hooks, TO_PATCH)

    def test_install(self):
        hooks.hooks.execute(['hooks/install'])
        self.assertTrue(self.execd_preinstall.called)

    @patch.object(hooks, 'storage_backend')
    def test_upgrade_charm_related(self, _storage_backend):
        self.relation_ids.return_value = ['storage-backend:1']
        hooks.hooks.execute(['hooks/upgrade-charm'])
        _storage_backend.assert_called_with('storage-backend:1')

    @patch.object(hooks, 'storage_backend')
    def test_config_change_related(self, _storage_backend):
        self.relation_ids.return_value = ['storage-backend:1']
        hooks.hooks.execute(['hooks/upgrade-charm'])
        _storage_backend.assert_called_with('storage-backend:1')

    def test_storage_backend_joined(self):
        def func():
            return {'test': 1}
        self.service_name.return_value = 'cinder-vmware'
        self.VMwareSubordinateContext.return_value = func
        hooks.hooks.execute(['hooks/storage-backend-relation-joined'])
        self.relation_set.assert_called_with(
            relation_id=None,
            backend_name='cinder-vmware',
            subordinate_configuration=json.dumps({'test': 1})
            )

    def test_storage_backend_joined_direct_call(self):
        def func():
            return {'test': 1}
        self.service_name.return_value = 'cinder-vmware'
        self.VMwareSubordinateContext.return_value = func
        hooks.storage_backend('storage-backend:1')
        self.relation_set.assert_called_with(
            relation_id='storage-backend:1',
            backend_name='cinder-vmware',
            subordinate_configuration=json.dumps({'test': 1})
            )
